@@ -69,11 +69,14 @@ signupSupport = {{signup_support}}
 allowChangeSigninMode = {{allow_change_signin_mode}}
 allowAnonymousChangePassword = {{allow_anonymous_change_password}}
 allowProjectResourceMonitor = {{allow_project_resource_monitor}}
+allowManualImageNameForSession = {{allow_manual_image_name_for_session}}
 autoLogout = {{auto_logout}}
+debug = {{webui_debug}}
 
 [resources]
 openPortToPublic = {{open_port_to_public}}
 maxCPUCoresPerContainer = {{max_cpu_cores_per_container}}
+maxMemoryPerContainer = {{max_memory_per_container}}
 maxCUDADevicesPerContainer = {{max_cuda_devices_per_container}}
 maxCUDASharesPerContainer = {{max_cuda_shares_per_container}}
 maxShmPerContainer = {{max_shm_per_container}}
@@ -147,6 +150,7 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
         if 'resources' in config:
             open_port_to_public = 'true' if config['resources'].get('open_port_to_public') else 'false'
             max_cpu_cores_per_container = config['resources'].get('max_cpu_cores_per_container', 64)
+            max_memory_per_container = config['resources'].get('max_memory_per_container', 64)
             max_cuda_devices_per_container = config['resources'].get(
                     'max_cuda_devices_per_container', 16)
             max_cuda_shares_per_container = config['resources'].get(
@@ -156,6 +160,7 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
         else:
             open_port_to_public = 'false'
             max_cpu_cores_per_container = 64
+            max_memory_per_container = 64
             max_cuda_devices_per_container = 16
             max_cuda_shares_per_container = 16
             max_shm_per_container = 2
@@ -178,10 +183,14 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
                 'true' if config['service'].get('allow_anonymous_change_password') else 'false',
             'allow_project_resource_monitor':
                 'true' if config['service']['allow_project_resource_monitor'] else 'false',
+            'allow_manual_image_name_for_session':
+                'true' if config['service'].get('allow_manual_image_name_for_session') else 'false',
+            'webui_debug': 'true' if config['service'].get('webui_debug') else 'false',
             'auto_logout':
-                'true' if config['service'].get('auto_logout') else 'false',
+                'true' if config['session'].get('auto_logout') else 'false',
             'open_port_to_public': open_port_to_public,
             'max_cpu_cores_per_container': max_cpu_cores_per_container,
+            'max_memory_per_container': max_memory_per_container,
             'max_cuda_devices_per_container': max_cuda_devices_per_container,
             'max_cuda_shares_per_container': max_cuda_shares_per_container,
             'max_shm_per_container': max_shm_per_container,
@@ -381,6 +390,14 @@ async def logout_handler(request: web.Request) -> web.Response:
     return web.Response(status=201)
 
 
+async def webserver_healthcheck(request: web.Request) -> web.Response:
+    result = {
+        'version': __version__,
+        'details': 'Success'
+    }
+    return web.json_response(result)
+
+
 async def token_login_handler(request: web.Request) -> web.Response:
     config = request.app['config']
 
@@ -423,6 +440,9 @@ async def token_login_handler(request: web.Request) -> web.Response:
         )
         assert anon_api_config.is_anonymous
         async with APISession(config=anon_api_config) as api_session:
+            # Send X-Forwarded-For header for token authentication with the client IP.
+            _headers = {'X-Forwarded-For': request.headers.get('X-Forwarded-For', '')}
+            api_session.aiohttp_session.headers.update(_headers)
             # Instead of email and password, cookie token will be used for auth.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
             token = await api_session.User.authorize('fake-email', 'fake-pwd')
@@ -507,6 +527,7 @@ async def server_main(loop, pidx, args):
     cors.add(app.router.add_route('POST', '/server/token-login', token_login_handler))
     cors.add(app.router.add_route('POST', '/server/login-check', login_check_handler))
     cors.add(app.router.add_route('POST', '/server/logout', logout_handler))
+    cors.add(app.router.add_route('GET', '/func/ping', webserver_healthcheck))
     cors.add(app.router.add_route('GET', '/func/{path:hanati/user}', anon_web_plugin_handler))
     cors.add(app.router.add_route('GET', '/func/{path:cloud/.*$}', anon_web_plugin_handler))
     cors.add(app.router.add_route('POST', '/func/{path:cloud/.*$}', anon_web_plugin_handler))
